@@ -20,7 +20,7 @@ team_name_fn <- function(var) {
 
 # helper column to avoid join errors
 drop.cols <- c(
-  "game_id", "week",  "model_roof", "era3", "era4", "era", "home_total", "away_total", "total_line", "spread_line",
+  "game_id", "week",  "model_roof", "roof", "era3", "era4", "era", "home_total", "away_total", "total_line", "spread_line",
   "retractable", "dome", "outdoors"
 )
 
@@ -32,7 +32,8 @@ get_games_file <- function() {
     mutate(
       type = if_else(game_type == "REG", "reg", "post"),
       model_roof = if_else(roof == "open" | roof == "closed" | is.na(roof), "retractable", roof),
-      # don't use this for games earlier than 2014
+      # for EP model: don't use this for games earlier than 2014
+      era0 = 0, era1 = 0, era2 = 0,
       era3 = dplyr::if_else(season > 2013 & season <= 2017, 1, 0),
       era4 = dplyr::if_else(season > 2017, 1, 0),
       # for field goal model
@@ -41,12 +42,13 @@ get_games_file <- function() {
       away_total = (total_line - spread_line) / 2,
       retractable = dplyr::if_else(model_roof == 'retractable', 1, 0),
       dome = dplyr::if_else(model_roof == 'dome', 1, 0),
-      outdoors = dplyr::if_else(model_roof == 'outdoors', 1, 0)
+      outdoors = dplyr::if_else(model_roof == 'outdoors', 1, 0),
+      roof = model_roof
     ) %>%
     dplyr::mutate_at(dplyr::vars("home_team", "away_team"), team_name_fn) %>%
     dplyr::select(
       game_id, season, type, week, away_team, home_team, espn,
-      model_roof, era3, era4, era, home_total, away_total, total_line, spread_line,
+      model_roof, roof, era0, era1, era2, era3, era4, era, home_total, away_total, total_line, spread_line,
       retractable, dome, outdoors
     ) %>%
     return()
@@ -58,27 +60,34 @@ prepare_df <- function(df) {
   df %>%
     # if an nflfastR df is passed, need to drop all this so we don't get redundant cols
     dplyr::select(-tidyselect::any_of(drop.cols)) %>%
-    left_join(.games_nfl4th, by = c("home_team", "away_team", "type", "season")) %>%
+    left_join(.games_nfl4th(), by = c("home_team", "away_team", "type", "season")) %>%
     mutate(
-      receive_2h_ko = case_when(
-        # 1st half, home team opened game with kickoff, away team has ball
-        qtr <= 2 & home_opening_kickoff == 1 & posteam == away_team ~ 1,
-        # 1st half, away team opened game with kickoff, home team has ball
-        qtr <= 2 & home_opening_kickoff == 0 & posteam == home_team ~ 1,
+      home_receive_2h_ko = dplyr::case_when(
+        # home got it first
+        .data$qtr <= 2 & .data$home_opening_kickoff == 1 ~ -1,
+        # away got it first
+        .data$qtr <= 2 & .data$home_opening_kickoff == 0 ~ 1,
+        # it's the 2nd half
         TRUE ~ 0
       ),
       down = 4,
       half_seconds_remaining = if_else(qtr == 2 | qtr == 4, quarter_seconds_remaining, quarter_seconds_remaining + 900),
       game_seconds_remaining = if_else(qtr <= 2, half_seconds_remaining + 1800, half_seconds_remaining),
+
+      # added
+      elapsed_share = (3600 - .data$game_seconds_remaining) / 3600,
+      spread_time = .data$spread_line * exp(-4 * .data$elapsed_share),
+
+      # useful for lots of stuff later
+
       posteam_spread = if_else(posteam == home_team, spread_line, -spread_line),
       posteam_total = if_else(posteam == home_team, home_total, away_total),
       posteam_spread = dplyr::if_else(posteam == home_team, spread_line, -1 * spread_line),
 
-      # useful for lots of stuff later
-
       home_timeouts_remaining = if_else(posteam == home_team, posteam_timeouts_remaining, defteam_timeouts_remaining),
       away_timeouts_remaining = if_else(posteam == away_team, posteam_timeouts_remaining, defteam_timeouts_remaining),
       original_posteam = posteam
+
     ) %>%
     return()
 
@@ -91,10 +100,6 @@ flip_team <- function(df) {
     mutate(
       # switch posteam
       posteam = if_else(home_team == posteam, away_team, home_team),
-
-      # update timeouts
-      posteam_timeouts_remaining = if_else(posteam == away_team, away_timeouts_remaining, home_timeouts_remaining),
-      defteam_timeouts_remaining = if_else(posteam == home_team, away_timeouts_remaining, home_timeouts_remaining),
       # swap score
       score_differential = -score_differential,
       # 1st and 10
@@ -105,13 +110,7 @@ flip_team <- function(df) {
       game_seconds_remaining = game_seconds_remaining - 6,
       # don't let seconds go negative
       half_seconds_remaining = if_else(half_seconds_remaining < 0, 0, half_seconds_remaining),
-      game_seconds_remaining = if_else(game_seconds_remaining < 0, 0, game_seconds_remaining),
-      # flip receive_2h_ko var
-      receive_2h_ko = case_when(
-        qtr <= 2 & receive_2h_ko == 0 ~ 1,
-        qtr <= 2 & receive_2h_ko == 1 ~ 0,
-        TRUE ~ receive_2h_ko
-      )
+      game_seconds_remaining = if_else(game_seconds_remaining < 0, 0, game_seconds_remaining)
     ) %>%
     return()
 
@@ -133,8 +132,6 @@ flip_half <- function(df) {
         TRUE ~ posteam
       ),
       qtr = ifelse(end_of_half == 1, 3L, qtr),
-      posteam_timeouts_remaining = ifelse(end_of_half == 1, 3L, posteam_timeouts_remaining),
-      defteam_timeouts_remaining = ifelse(end_of_half == 1, 3L, defteam_timeouts_remaining),
       down = ifelse(end_of_half == 1, 1, down),
       ydstogo = ifelse(end_of_half == 1, 10L, ydstogo),
       yardline_100 = ifelse(end_of_half == 1, 75L, yardline_100),
@@ -143,7 +140,7 @@ flip_half <- function(df) {
       score_differential = ifelse(
         posteam != prior_posteam & end_of_half == 1, -score_differential, score_differential
       ),
-      receive_2h_ko = ifelse(end_of_half == 1, 0, receive_2h_ko)
+      home_receive_2h_ko = ifelse(end_of_half == 1, 0, home_receive_2h_ko)
     ) %>%
     select(-prior_posteam, -end_of_half) %>%
     return()
@@ -156,6 +153,7 @@ end_game_fn <- function(pbp) {
 
   pbp %>%
     mutate(
+      defteam_timeouts_remaining = ifelse(posteam == home_team, away_timeouts_remaining, home_timeouts_remaining),
       vegas_wp = case_when(
         score_differential > 0 & game_seconds_remaining < 120 & defteam_timeouts_remaining == 0 ~ 0,
         score_differential > 0 & game_seconds_remaining < 80 & defteam_timeouts_remaining == 1 ~ 0,
@@ -180,7 +178,7 @@ prepare_nflfastr_data <- function(pbp) {
       type = ifelse(tolower(season_type) == "reg", "reg", "post")
     ) %>%
     filter(
-      game_seconds_remaining > 30,
+      game_seconds_remaining > 15,
       !is.na(half_seconds_remaining),
       !is.na(qtr),
       !is.na(posteam),
@@ -211,8 +209,18 @@ rds_from_url <- function(.url){
 
 load_fd_model <- function() {
   fd_model <- NULL
-  con <- url("https://github.com/guga31bb/fourth_calculator/blob/main/data/fd_model.Rdata?raw=true")
+  con <- url("https://github.com/guga31bb/fourth_calculator/blob/main/data/fd_model_v2.Rdata?raw=true")
   try(load(con), silent = TRUE)
   close(con)
   fd_model
 }
+
+load_wp_model <- function() {
+  wp_model <- NULL
+  con <- url("https://github.com/guga31bb/fourth_calculator/blob/main/data/home_wp_model.Rdata?raw=true")
+  try(load(con), silent = TRUE)
+  close(con)
+  wp_model
+}
+
+
